@@ -2,19 +2,20 @@
 /*  GMime
  *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -26,6 +27,17 @@
 
 #include "gmime-filter-yenc.h"
 
+
+/**
+ * SECTION: gmime-filter-yenc
+ * @title: GMimeFilterYenc
+ * @short_description: yEncode or yDecode
+ * @see_also: #GMimeFilter
+ *
+ * A #GMimeFilter used to encode or decode the Usenet yEncoding.
+ **/
+
+
 static void g_mime_filter_yenc_class_init (GMimeFilterYencClass *klass);
 static void g_mime_filter_yenc_init (GMimeFilterYenc *filter, GMimeFilterYencClass *klass);
 static void g_mime_filter_yenc_finalize (GObject *object);
@@ -279,7 +291,7 @@ g_mime_filter_yenc_new (GMimeFilterYencDirection direction)
 {
 	GMimeFilterYenc *new;
 	
-	new = g_object_new (GMIME_TYPE_FILTER_YENC, NULL, NULL);
+	new = g_object_new (GMIME_TYPE_FILTER_YENC, NULL);
 	new->direction = direction;
 	
 	switch (direction) {
@@ -523,7 +535,7 @@ g_mime_ydecode_step (const unsigned char *in, size_t inlen, unsigned char *out,
  * should reuse @state.
  *
  * Along the same lines, @pcrc and @crc should be initialized to
- * GMIME_YENCODE_CRC_INIT before using.
+ * #GMIME_YENCODE_CRC_INIT before using.
  *
  * Returns the number of bytes encoded.
  **/
